package com.ruoyi.warehouseBusiness.excel;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.ruoyi.common.annotation.Excel;

import java.util.Date;

/**
 * 入库导出
 *
 * @author ruoyi
 * @date 2020-12-11
 */
public class GoodsTransfer {
    private static final long serialVersionUID = 1L;

    /**
     * 创建者
     */
    @Excel(name = "制单人")
    private String createBy;

    /**
     *  库存明细 1 未入账  2 未完成所有入账  6  已入账
     */
    @Excel(name = "货转状态")
    private String fItemsStatus;

    /**
     * 客户名称，t_corps 中的no或 name，模糊查找选择后，存储id，显示name
     */
    @Excel(name = "货权方")
    private String fCorpid;

    /**
     * 客户名称，t_corps 中的no或 name，模糊查找选择后，存储id，显示name
     */
    @Excel(name = "转货权方")
    private String fTocorpid;


    /** 明细品名合计 */
    @Excel(name = "品名")
    private String fProductName;

    /**
     * 唛头
     */
    @Excel(name = "品牌")
    private String fMarks;

    /**
     * 唛头
     */
    @Excel(name = "业务编号")
    private String fBillno;

    /**
     * 入库日期
     */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "货转日期", width = 30, dateFormat = "yyyy-MM-dd")
    private Date fBsdate;

    /**
     * 仓库
     */
    @Excel(name = "贸易方式")
    private String fTrademodeid;

    /**
     * 仓库
     */
    @Excel(name = "仓库")
    private String fWarehouseid;

    /**
     * 件数,由明细表自动合计生成
     */
    @Excel(name = "件数")
    private Integer fQty;

    /**
     * 毛重，由明细表自动合计生成
     */
    @Excel(name = "毛重（KG）")
    private Float fGrossweight;

    /**
     * 净重，由明细表自动合计生成
     */
    @Excel(name = "净重（KG）")
    private Float fNetweight;


    /**
     * 状态(数据字典),N 入（出）库中，T入（出）库完成，状态为完成不能删除，状态变化，用邮件、微信通知客户。
     */
    @Excel(name = "费用状态")
    private String fBillstatus;


    public String getCreateBy() {
        return createBy;
    }

    public void setCreateBy(String createBy) {
        this.createBy = createBy;
    }

    public String getfItemsStatus() {
        return fItemsStatus;
    }

    public void setfItemsStatus(String fItemsStatus) {
        this.fItemsStatus = fItemsStatus;
    }

    public String getfCorpid() {
        return fCorpid;
    }

    public void setfCorpid(String fCorpid) {
        this.fCorpid = fCorpid;
    }

    public String getfTocorpid() {
        return fTocorpid;
    }

    public void setfTocorpid(String fTocorpid) {
        this.fTocorpid = fTocorpid;
    }

    public String getfProductName() {
        return fProductName;
    }

    public void setfProductName(String fProductName) {
        this.fProductName = fProductName;
    }

    public String getfMarks() {
        return fMarks;
    }

    public void setfMarks(String fMarks) {
        this.fMarks = fMarks;
    }

    public String getfBillno() {
        return fBillno;
    }

    public void setfBillno(String fBillno) {
        this.fBillno = fBillno;
    }

    public Date getfBsdate() {
        return fBsdate;
    }

    public void setfBsdate(Date fBsdate) {
        this.fBsdate = fBsdate;
    }

    public String getfWarehouseid() {
        return fWarehouseid;
    }

    public void setfWarehouseid(String fWarehouseid) {
        this.fWarehouseid = fWarehouseid;
    }

    public Integer getfQty() {
        return fQty;
    }

    public void setfQty(Integer fQty) {
        this.fQty = fQty;
    }

    public Float getfGrossweight() {
        return fGrossweight;
    }

    public void setfGrossweight(Float fGrossweight) {
        this.fGrossweight = fGrossweight;
    }

    public Float getfNetweight() {
        return fNetweight;
    }

    public void setfNetweight(Float fNetweight) {
        this.fNetweight = fNetweight;
    }

    public String getfBillstatus() {
        return fBillstatus;
    }

    public void setfBillstatus(String fBillstatus) {
        this.fBillstatus = fBillstatus;
    }

    public String getfTrademodeid() {
        return fTrademodeid;
    }

    public void setfTrademodeid(String fTrademodeid) {
        this.fTrademodeid = fTrademodeid;
    }
}
